<%
'*********************************************************
'
'   Tektronix Windows 2000 Print Status ASP Page Project
'
'   Copyright (c) Tektronix, Inc. 1999
'
'   Description
'
'	Dynamic HTML functions.
'
'   History
'
'       Version 1.0 7/22/99     Greg Thornton
'	Version 1.1 8/11/99	Greg Thornton
'	Version 1.2 9/24/99	Greg Thornton, MS session variable bug
'
'*********************************************************

'*********************************************************
'
' Definitions
'
'*********************************************************

' The following tokens are used by DetermineTableArrangment() 
' to specify the content that should occupy a specific 
' NT5 Printer Status table cell.

Const HDR_TRAY			= 1
Const DATA_TRAY			= 2
Const HDR_SUPPLY 		= 3
Const DATA_SUPPLY		= 4
Const HDR_INFO			= 5
Const DATA_INFO			= 6
Const HDR_COUNT			= 7
Const DATA_COUNT		= 8
Const HDR_YOUR_PRINTER		= 9
Const DATA_YOUR_PRINTER		= 10
Const HDR_TEK_COM		= 11
Const DATA_TEK_COM		= 12
Const DATA_PAD			= 13
Const DATA_WHITE_PAD		= 14

' NT5 Printer Status table constants

Const INFO_CELL_COUNT		= 3
Const COUNT_CELL_COUNT		= 2
Const YOUR_PRINTER_CELL_COUNT	= 2
Const TEK_COM_CELL_COUNT	= 2
	
TRAY_LOC			= Array(0,0)
SUPPLY_LOC			= Array(0,1)


'**************************************************************************
' Name: DetermineTableArrangement
'
' Description:  
'	This function determines the arrangement for
'	the NT5 Printer Status HTML Table. The table is comprised
'	of the following sections: tray(s), supplies, SNMP info, 
'	page count, your printer, and tektronix.com.
'
'       The rules for the table layout are as follows:
'	1. The table is always 2 columns with a variable number of rows.
'	2. All sections have a header cell followed by one or more data
'	   cells immediately below the header in the same column.
' 	3. The tray section is always located in top left corner of the table.
' 	4. The supply section is always in the top right corner of the table.
' 	5. SNMP info and page count sections can be either be stacked (SNMP info on top)
'	   and located in the right or left column or alternatively be positioned 
'	   side by side starting at the same row. The arrangement selected is 
'	   the arrangement that yields the least amount of table rows.
' 	6. The your printer and tektronix.com sections are always located at the 
'	   bottom of the table starting at the same row. your printer is located
'	   in the left column, tektronix.com in the right column.
' Inputs:
'	Global variables snmpGpidInput and snmpGpidMarker.     
' Returns:  
'	This function returns an array dimensioned to the size of the 
'	NT5 printer status table and initialized with HDR_XXX and DATA_XXX 
'	constants which define the contents of each table cell.
'***************************************************************************

Function DetermineTableArrangement()
	Dim table_content
	Dim tray_cell_count, supply_cell_count
	Dim row_count, stacked_row_count, sbs_row_count, larger_row_count
	Dim info_loc, count_loc, your_printer_loc, tek_com_loc

	'*******************************************************
	' Get number of tray and supply cells including headers
	'*******************************************************
	tray_cell_count 	= UBound(snmpGpidInput, 2) + 2
	supply_cell_count 	= UBound(snmpGpidMarker, 2) + 2


	'*******************************************************
	' Determine row count if info and count are stacked
	'*******************************************************
	If tray_cell_count <= supply_cell_count Then
		stacked_row_count = tray_cell_count + INFO_CELL_COUNT + COUNT_CELL_COUNT
	Else
		stacked_row_count = supply_cell_count + INFO_CELL_COUNT + COUNT_CELL_COUNT
	End If

	'*******************************************************
	' Determine row count if info and count are side by side
	'*******************************************************
	If INFO_CELL_COUNT >= COUNT_CELL_COUNT Then
		larger_row_count = INFO_CELL_COUNT
	Else
		larger_row_count = COUNT_CELL_COUNT
	End If

	If tray_cell_count >= supply_cell_count Then
		sbs_row_count = tray_cell_count + larger_row_count
	Else
		sbs_row_count = supply_cell_count + larger_row_count
	End If

	If stacked_row_count < sbs_row_count Then		
		'*******************************************************
		' Stack info and count sections
		'*******************************************************
		If tray_cell_count <= supply_cell_count Then
			' Positioned in left table column
			info_loc	= Array(tray_cell_count,0)
			count_loc	= Array(tray_cell_count + INFO_CELL_COUNT,0)
			row_count 	= tray_cell_count + INFO_CELL_COUNT + COUNT_CELL_COUNT
			If row_count < supply_cell_count Then
				row_count = supply_cell_count
			End If
		Else
			' Positioned in right table column
			info_loc	= Array(supply_cell_count,1)
			count_loc	= Array(supply_cell_count + INFO_CELL_COUNT, 1)
			row_count 	= supply_cell_count + INFO_CELL_COUNT + COUNT_CELL_COUNT
			If row_count < tray_cell_count Then
				row_count = tray_cell_count 
			End If
		End If
	Else

		'*******************************************************
		' Side by side info and count sections
		'*******************************************************
		If tray_cell_count >= supply_cell_count Then

			info_loc	= Array(tray_cell_count,0)
			count_loc	= Array(tray_cell_count,1)
			row_count	= tray_cell_count + larger_row_count
		Else

			info_loc	= Array(supply_cell_count,0)
			count_loc	= Array(supply_cell_count,1)
			row_count	= supply_cell_count + larger_row_count

		End If
	
	End If
	
	'*******************************************************
	' Locate your printer and tektronix.com sections
	'*******************************************************
	your_printer_loc 		= Array(row_count,1)
	tek_com_loc			= Array(row_count,0)

	If YOUR_PRINTER_CELL_COUNT >= TEK_COM_CELL_COUNT Then
		row_count		= row_count + YOUR_PRINTER_CELL_COUNT
	Else
		row_count		= row_count + TEK_COM_CELL_COUNT
	End If

	'*******************************************************
	' Define table content
	'*******************************************************
	ReDim table_content(row_count - 1, 1)


	'*******************************************************
	' Fill entire table with pads

	'*******************************************************
	fill = DATA_PAD * 256
	For i = 0 To row_count - 1
		For j = 0 To 1
			table_content(i,j) = fill
		Next
	Next

	'*******************************************************
	' Set the tray section content specifiers
	'*******************************************************
	table_content(TRAY_LOC(0),TRAY_LOC(1)) 				= HDR_TRAY * 256
	For i = 0 To UBound(snmpGpidInput,2)
		table_content(TRAY_LOC(0)+1+i,TRAY_LOC(1)) 		= DATA_TRAY * 256 + i
	Next

	'*******************************************************
	' Set the supply section content specifiers
	'*******************************************************
	table_content(SUPPLY_LOC(0),SUPPLY_LOC(1)) 			= HDR_SUPPLY * 256
	For i = 0 To UBound(snmpGpidMarker,2)
		table_content(SUPPLY_LOC(0)+1+i,SUPPLY_LOC(1)) 		= DATA_SUPPLY * 256 + i
	Next

	'*******************************************************
	' Set the SNMP info section content specifiers
	'*******************************************************
	table_content(info_loc(0),info_loc(1)) 				= HDR_INFO * 256
	For i = 0 To INFO_CELL_COUNT - 2
		table_content(info_loc(0)+1+i,info_loc(1)) 		= DATA_INFO * 256 + i
	Next

	'*******************************************************
	' Set the page count content specifiers
	'*******************************************************
	table_content(count_loc(0),count_loc(1)) 			= HDR_COUNT * 256
	For i = 0 To COUNT_CELL_COUNT - 2
		table_content(count_loc(0)+1+i,count_loc(1)) 		= DATA_COUNT * 256 + i
	Next

	'*******************************************************
	' Set the your printer content specifiers
	' The 540 does not implement PhaserLink so leave these
	' cells blank.
	'*******************************************************
	If model = M_540 Then
		hdr_content  = DATA_PAD
		data_content = DATA_WHITE_PAD
	Else
		hdr_content  = HDR_YOUR_PRINTER
		data_content = DATA_YOUR_PRINTER
	End If

	table_content(your_printer_loc(0),your_printer_loc(1))			= hdr_content * 256
	For i = 0 To YOUR_PRINTER_CELL_COUNT - 2
		table_content(your_printer_loc(0)+1+i,your_printer_loc(1)) 	= data_content * 256 + i
	Next

		

	'*******************************************************
	' Set the tektronix.com content specifiers
	'*******************************************************
	table_content(tek_com_loc(0),tek_com_loc(1))			= HDR_TEK_COM * 256
	For i = 0 To YOUR_PRINTER_CELL_COUNT - 2
		table_content(tek_com_loc(0)+1+i,tek_com_loc(1)) 	= DATA_TEK_COM * 256 + i
	Next
	
	DetermineTableArrangement = table_content
	
End Function

Function htmlHdrCell(text)
	htmlHdrCell = "<td ALIGN=LEFT VALIGN=BOTTOM WIDTH=""240"" BGCOLOR=""#FF9900""><font color=""#FFFFFF""><b>" & text & "</b></font></td>" & vbCr
End Function

Function htmlDataCell(textTitle, textData)
	Dim htmlBuf	
	If strComp(textTitle, "") = 0 Then
		htmlDataCell = "<td BGCOLOR=""#CCCCCC"" WIDTH=""270"" align=""left"" valign=""top"">" & textData & "</td>" & vbCr
	Else
		htmlDataCell = "<td BGCOLOR=""#CCCCCC"" ><b>" & textTitle & "</b> <br>" & textData & "</td>" & vbCr
	End If
End Function


Function textCookedGpidInputStatus(index)
	Dim textBuf, trayStatus, strTrayStatus

	If snmpGpidInput(INPUT_MAX_CAPACITY,index) = 0 AND snmpGpidInput(INPUT_TRAY_TYPE,index) = SNMP_GPID_INPUT_TRAY_TYPE_REMOVEABLE Then
		trayStatus = REMOVED
	ElseIf snmpGpidInput(INPUT_CURRENT_LEVEL, index) = 0 Then
		trayStatus = T_EMPTY
	ElseIf snmpGpidInput(INPUT_STATUS, index) = SNMP_GPID_INPUT_STATUS_LOW Then
		trayStatus = LOW
	Else
		trayStatus = OK
	End If

	If trayStatus = REMOVED OR (trayStatus = T_EMPTY AND (snmpGpidInput(INPUT_MEDIA_SIZE,index) = SNMP_GPID_INPUT_MEDIA_SIZE_OTHER OR snmpGpidInput(INPUT_MEDIA_SIZE,index) = SNMP_GPID_INPUT_MEDIA_SIZE_UNKNOWN) AND (snmpGpidInput(INPUT_MEDIA_TYPE,index) = SNMP_GPID_INPUT_MEDIA_TYPE_OTHER OR snmpGpidInput(INPUT_MEDIA_TYPE,index) = SNMP_GPID_INPUT_MEDIA_TYPE_UNKNOWN)) Then
		textBuf = text(trayStatus)
	Else
		textBuf = textGpidInputMediaSize(		snmpGpidInput(INPUT_MEDIA_SIZE,index)) & ","
		textBuf = textBuf & textGpidInputMediaType(	snmpGpidInput(INPUT_MEDIA_TYPE,index))
		If NOT trayStatus = OK Then
			textBuf = textBuf & text(SEPERATOR) & text(trayStatus)
		End If
	End If

	textCookedGpidInputStatus = textBuf
End Function

Function textCookedGpidMarkerSuppliesStatus(index,model)
	Dim textBuf, pages_remaining

	Select Case model

		Case M_780
			' All 780 supplies report this way
			textBuf = cStr(snmpGpidMarker(MARKER_SUPPLY_REMAINING,index)) & text(PERCENT)

		Case M_740
			If snmpGpidMarker(MARKER_TYPE,index) = toner Then
				textBuf = textGpidMarkerSuppliesStatusAlt(snmpGpidMarker(MARKER_SUPPLY_STATUS,index)) 
			Else
				textBuf = cStr(snmpGpidMarker(MARKER_SUPPLY_REMAINING,index)) & text(PERCENT)
			End If

		Case M_560, M_550, M_540
			If snmpGpidMarker(MARKER_MAX_LIFE,index) > 0 Then

				pages_remaining = snmpGpidMarker(MARKER_MAX_LIFE,index) - snmpGpidMarker(MARKER_LIFE,index)
				textBuf = cStr(cInt((100 * pages_remaining) / snmpGpidMarker(MARKER_MAX_LIFE,index))) & text(PERCENT)

			ElseIf snmpGpidMarker(MARKER_MAX_CAPACITY,index) > 0 AND snmpGpidMarker(MAKER_LEVEL,index) >= 0 Then

				textBuf = cStr(CInt( (100 * (CSng(snmpGpidMarker(MAKER_LEVEL,index)))) / (CSng(snmpGpidMarker(MARKER_MAX_CAPACITY,index))) )) & text(PERCENT)
	
			Else
				If snmpGpidMarker(MARKER_TYPE,index) = toner Then
					textBuf = textGpidMarkerSuppliesStatusAlt(snmpGpidMarker(MARKER_SUPPLY_STATUS,index)) 
				Else
					textBuf = textGpidMarkerSuppliesStatus(snmpGpidMarker(MARKER_SUPPLY_STATUS,index)) 
				End If

			End If

		Case Else
			If snmpGpidMarker(MARKER_MAX_LIFE,index) > 0 Then

				If NOT model = M_840 Then
					pages_remaining = snmpGpidMarker(MARKER_MAX_LIFE,index) - snmpGpidMarker(MARKER_LIFE,index)
				Else
					pages_remaining = snmpGpidMarker(MARKER_LIFE,index)
				End If

				If pages_remaining < 0 Then
					pages_remaining = 0
				End If

				textBuf = cStr(pages_remaining) & " " & text(PAGES)

			ElseIf snmpGpidMarker(MARKER_MAX_CAPACITY,index) > 3 AND snmpGpidMarker(MAKER_LEVEL,index) >= 0 Then

				textBuf = cStr(CInt( (100 * (CSng(snmpGpidMarker(MAKER_LEVEL,index)))) / (CSng(snmpGpidMarker(MARKER_MAX_CAPACITY,index))) )) & text(PERCENT)
	
			Else
				If snmpGpidMarker(MARKER_TYPE,index) = wax_solid Then
					textBuf = textGpidMarkerSuppliesStatusAlt(snmpGpidMarker(MARKER_SUPPLY_STATUS,index)) 
				Else
					textBuf = textGpidMarkerSuppliesStatus(snmpGpidMarker(MARKER_SUPPLY_STATUS,index)) 
				End If

			End If

	End Select

	textCookedGpidMarkerSuppliesStatus = textBuf
End Function

Function textCookedGpidMarkerSuppliesType(index,model)
	Dim textBuf, textColor

	If snmpGpidMarker(MARKER_TYPE,index) = SNMP_GPID_MARKER_SUPPLIES_TYPE_OTHER Then
		textCookedGpidMarkerSuppliesType = textGpidMarkerSuppliesColorId(snmpGpidMarker(MARKER_COLORANT,index),model)
	Else 
		Select Case snmpGpidMarker(MARKER_COLORANT,index)
			Case SNMP_GPID_MARKER_SUPPLIES_COLORANTID_C, SNMP_GPID_MARKER_SUPPLIES_COLORANTID_M,SNMP_GPID_MARKER_SUPPLIES_COLORANTID_Y, SNMP_GPID_MARKER_SUPPLIES_COLORANTID_K
				textColor = textGpidMarkerSuppliesColorId(snmpGpidMarker(MARKER_COLORANT,index),model) & " "
			Case Else
				textColor = ""
		End Select
		textCookedGpidMarkerSuppliesType = textColor & textGpidMarkerSuppliesType(snmpGpidMarker(MARKER_TYPE,index),model)
	End If
End Function

'**************************************************************************
' Name: AlertDuplicate
'
' Description:  
'	Check DisplayedAlerts for the presence of AlertCode and return
'	TRUE if found, otherwise return FALSE. Alert duplicates can exist
' 	when the same conditions exist on multiple devices. Since the Error
'	and warning messages do not name the device, duplicates should not
'	be displayed. 
'
'**************************************************************************
Function AlertDuplicate(DisplayedAlerts, AlertCode)
	Dim Duplicate

	Duplicate = FALSE

	For i = 0 To UBound(DisplayedAlerts, 1)

		If DisplayedAlerts(i) = -1 Then
			Exit For
		End If

		If DisplayedAlerts(i) = AlertCode Then
			Duplicate = TRUE
			Exit For
		End If
	Next
	AlertDuplicate = Duplicate
End Function

'**************************************************************************
' Name: CriticalError
'
' Description:  
'	Check snmpPrtAlert for the presence of a critical error and return
'	TRUE if found, otherwise return FALSE.
'
'**************************************************************************
Function CriticalError()
	CriticalError = FALSE

	If IsArray(snmpPrtAlert) Then
		For i = 0 to UBound(snmpPrtAlert,2)
			If snmpPrtAlert(ALERT_LEVEL,i) = prtAlertSeverityLevelCritical Then
				CriticalError = TRUE
				Exit For
			End If
		NEXT
	End If
End Function

'**************************************************************************
' Name: htmlPrinterAdvisoryTable
'
' Description:  
'	This function generates the HTML for the NT5 Printer Advisory HTML Table. 
'	The HTML is written directly to the repsonse buffer. The advisory table
'	consists of a single row with 3 columns. The left table column contains
'	a status GIF, the middle column contains status, error, and warning text, 
'	and the right column contains a Tektronix logo.
' Inputs:
'	Global variables snmpGpidGeneral and snmpPrtAlert.     
' Returns:  
'	None.
'**************************************************************************
Function htmlPrinterAdvisoryTable( model )

	Dim htmlGifName, htmlGifColor, htmlGifPrinter

	'*******************************************************
	' Determine Status Gif file name
	'*******************************************************

	Select Case snmpGpidGeneral(GENERAL_STATUS)
		Case critical, critical_and_non_critical 	htmlGifColor = "red"
		Case non_critical, waiting 			htmlGifColor = "yel"
		Case Else					htmlGifColor = "gre"
	End Select

	Select Case model
		Case M340, M_350, M_360, M_380, M_840		htmlGifPrinter = "840"
		Case Else					htmlGifPrinter = "740"
	End Select

	htmlGifName = """e" & htmlGifPrinter & "x48" & htmlGifColor & ".gif"""

	'*******************************************************
	' Generate Status Gif
	'*******************************************************

	Response.Write( "<table WIDTH=""540"" >" & vbCr & "<tr>" & vbCr )
	Response.Write( "<td BGCOLOR=""#FFFFFF"" ALIGN=LEFT VALIGN=TOP WIDTH=""10""><img SRC=" & htmlGifName & "></td>")

	'*******************************************************
	' Generate general status text only if a critical error does not exist
	'*******************************************************

	Response.Write( "<td ALIGN=LEFT VALIGN=TOP WIDTH=""330"">" )
	If NOT IsArray(snmpPrtAlert) OR NOT CriticalError() Then
		Response.Write(vbCr & "<b>" & textGpidGeneralPrinterBusy(snmpGpidGeneral(GENERAL_PRINTER_BUSY)) & "</b><br>")
	End If

	'*******************************************************	
	' Generate Error and Warning Text 
	'*******************************************************

	If IsArray(snmpPrtAlert) Then

		reDim DisplayedAlerts(UBound(snmpPrtAlert,2))
		For i = 0 To UBound(snmpPrtAlert,2)
			DisplayedAlerts(i) = -1
		Next
		
		j = 0

		' First Error Text
		For i = 0 To UBound(snmpPrtAlert, 2)
			If snmpPrtAlert(ALERT_LEVEL, i) = prtAlertSeverityLevelCritical Then
				If NOT AlertDuplicate(DisplayedAlerts, snmpPrtAlert(ALERT_CODE, i)) Then
					DisplayedAlerts(j) = snmpPrtAlert(ALERT_CODE, i)
					j = j + 1
					Response.Write( vbCr & "<b>" & textPrtAlertCode(snmpPrtAlert(ALERT_CODE, i)) & "</b><br>")
				End If
			End If
		Next

		' Then Warning Text
		For i = 0 To UBound(snmpPrtAlert, 2)
			If snmpPrtAlert(ALERT_LEVEL, i) = prtAlertSeverityLevelWarning Then
				If NOT AlertDuplicate(DisplayedAlerts, snmpPrtAlert(ALERT_CODE, i)) Then
					DisplayedAlerts(j) = snmpPrtAlert(ALERT_CODE, i)
					j = j + 1
					Response.Write( vbCr & "<b>" & textPrtAlertCode(snmpPrtAlert(ALERT_CODE, i)) & "</b><br>")
				End If
			End If
		Next
	End If

	'*******************************************************
	' Generate logo gif
	'*******************************************************

	Response.Write( vbCr & "</td>" & vbCr & "<td ALIGN=RIGHT VALIGN=TOP WIDTH=""200""><img src=""logo.jpg""></td>" & vbCr & "</tr></table>" )

End Function


'**************************************************************************
' Name: GeneratePrinterStatusTable
'
' Description:  
'	This function generates the HTML for the NT5 Printer Status HTML Table. 
'	The HTML is written directly to the repsonse buffer. The table is comprised 
'	of the following sections: tray(s), supplies, SNMP info, page count, 
'	your printer, and tektronix.com. 
' Inputs:
'	Global variables snmpGpidInput and snmpGpidMarker.     
' Returns:  
'	None.
'**************************************************************************


Function htmlPrinterStatusTable(model)

	Dim table_content, i, j, k, t1, t2

	table_content = DetermineTableArrangement()

	Response.Write(vbCr & "<table WIDTH=""540"" >" & vbCr )

	'*******************************************************
	' For each table row
	'*******************************************************
	For i = 0 To UBound(table_content,1)

		Response.Write("<tr>" & vbCr )

		'*******************************************************
		' For each row column
		'*******************************************************		
		For j = 0 To 1
			Select Case table_content(i,j) \ 256

				Case HDR_TRAY

					Response.Write(htmlHdrCell(text(PAPER_TRAYS)))

				Case DATA_TRAY

					' Get the tray index number
					k  = table_content(i,j) - (DATA_TRAY * 256)
					t1 = textGpidInputTrayId(snmpGpidInput(INPUT_TRAY_ID,k))
					t2 = textCookedGpidInputStatus(k)
					Response.Write(htmlDataCell(t1, t2))

				Case HDR_SUPPLY

					Select Case model
						Case M_340, M_350, M_360, M_840
							Response.Write(htmlHdrCell(text(SUPPLIES)))						
						Case Else
							Response.Write(htmlHdrCell(text(SUPPLIES_REMAINING)))
					End Select

				Case DATA_SUPPLY

					' Get the supply index number
					k  = table_content(i,j) - (DATA_SUPPLY * 256)
					t1 = textCookedGpidMarkerSuppliesType(k, model)
					t2 = textCookedGpidMarkerSuppliesStatus(k, model)			
					Response.Write(htmlDataCell(t1, t2))

				Case HDR_INFO

					Response.Write(htmlHdrCell(text(LOCAL_PRINTER_INFO)))

				Case DATA_INFO

					If table_content(i,j) - (DATA_INFO * 256) = 0 Then
						Response.Write(htmlDataCell(text(CONTACT), snmpSysContact))
					Else
						Response.Write(htmlDataCell(text(PRINTER_LOCATION), snmpSysLocation))
					End If

				Case HDR_COUNT

					Response.Write(htmlHdrCell(text(PAGE_COUNT)))

				Case DATA_COUNT

					Response.Write(htmlDataCell("", cStr(snmpGpidMarkerLifeCounts) & " " & text(PAGES)))

				Case HDR_YOUR_PRINTER

					Response.Write(htmlHdrCell(text(YOUR_PRINTER)))

				Case DATA_YOUR_PRINTER

					t1 = "<td BGCOLOR=""#FFFFFF"" WIDTH=""270"" align=""left"" valign=""top"">" & vbCr 
					t1 = t1 & "<li><a href=""http://" & Request("MS_IPAddress") & "/button_config.html"" target=""_blank"">"
					t1 = t1 & text(PHASERLINK) & "</a>" & vbCr & "<br>"
					t1 = t1 & text(PRINTER_SETUP_DESC) & "</td>" & vbCr

					Response.Write(t1)

				Case HDR_TEK_COM

					Response.Write(htmlHdrCell(text(TEKTRONIX_COM)))

				Case DATA_TEK_COM

					tModel = replace(snmpGpidGeneral(GENERAL_PRODUCT)," ","+")
					tLink = "<li><a href = ""http://www.tek.com/cgi-bin/CPIDprinter?App=WA2000&Model=" & tModel 
					tLink = tLink & "&Language=" & htmlLanguage & "&Page=Color&PgName="

					t1 = "<td BGCOLOR=""#FFFFFF"" WIDTH=""270"" align=""left"" valign=""top"">" & vbCr
					t1 = t1 & tLink & "Color"" target=""_blank"">" 	& text(COLOR_CONNECTION) & "</a><br>" & vbCr
					t1 = t1 & tLink & "Man"" target=""_blank"">" 	& text(MANUALS) & "</a><br>" & vbCr
					t1 = t1 & tLink & "Tech"" target=""_blank"">" 	& text(TECHNICAL_SUPPORT) & "</a><br>" & vbCr
					t1 = t1 & tLink & "Reg"" target=""_blank"">" 	& text(REGISTER_PRINTER) & "</a><br>" & vbCr
					t1 = t1 & tLink & "Order"" target=""_blank"">"	& text(ORDER_SUPPLIES) & "</a></p></td>" & vbCr

					Response.Write(t1)

				Case DATA_PAD	
		
					Response.Write("<td BGCOLOR=""#CCCCCC"" WIDTH=""270"" align=""left"" valign=""top""> &nbsp;</td>" & vbCr)

				Case DATA_WHITE_PAD	
		
					Response.Write("<td BGCOLOR=""#FFFFFF"" WIDTH=""270"" align=""left"" valign=""top""> &nbsp;</td>" & vbCr)
			End Select		
		Next
		Response.Write("</tr>" & vbCr )
	Next
	Response.Write("</table>" & vbCr )
End Function

Function htmlErrorPage(proc)

	Response.Clear
	Response.Write("<b>" & text(ERROR_TITLE) & "</b><br><br>" & vbCr)
	Response.Write(text(ERROR_ADVICE_1) & "<br>" & vbCr)
	Response.Write(text(ERROR_ADVICE_2) & "<br><br>" & vbCr)
	Response.Write(text(PROCEDURE) & text(proc) & "<br>" & vbCr)
	Response.Write(text(SOURCE) & Err.Source & "<br>" & vbCr )
	Response.Write(text(CODE) & Err.Number & "<br>" & vbCr)
	Response.Write(text(DESCRIPTION) & Err.Description)
	Response.End

End Function

%>

